@@ -159,7 +159,6 @@ void DisplayVoices(FILE *f_out, char *language)
 	const char *p;
 	int len;
 	int count;
-	int scores = 0;
 	const espeak_VOICE *v;
 	const char *lang_name;
 	char age_buf[12];
@@ -176,7 +175,6 @@ void DisplayVoices(FILE *f_out, char *language)
 		voice_select.gender = 0;
 		voice_select.name = NULL;
 		voices = espeak_ListVoices(&voice_select);
-		scores = 1;
 	}
 	else
 	{
@@ -211,8 +209,6 @@ void DisplayVoices(FILE *f_out, char *language)
 			count++;
 			p += len+2;
 		}
-//		if(scores)
-//			fprintf(f_out,"%3d  ",v->score);
 		fputc('\n',f_out);
 	}
 }   //  end of DisplayVoices
@@ -286,7 +282,7 @@ static void CloseWaveFile()
 
 
 
-void MarkerEvent(int type, unsigned int char_position, int value, unsigned char *out_ptr)
+void MarkerEvent(int type, unsigned int char_position, int value, int value2, unsigned char *out_ptr)
 {//======================================================================================
 // Do nothing in the command-line version.
 	if(type == 2)
@@ -428,7 +424,7 @@ static int initialise(void)
 			fprintf(stderr,"Wrong version of espeak-data 0x%x (expects 0x%x) at %s\n",result,version_phdata,path_home);
 	}
 	LoadConfig();
-	SetVoiceStack(NULL);
+	SetVoiceStack(NULL, "");
 	SynthesizeInit();
 
 	for(param=0; param<N_SPEECH_PARAM; param++)
@@ -448,6 +444,8 @@ static void StopSpeak(int unused)
 	signal(SIGINT,StopSpeak);
 }  //  end of StopSpeak()
 
+
+
 #ifdef NEED_GETOPT
 	struct option {
 		char *name;
@@ -487,6 +485,7 @@ int main (int argc, char **argv)
 		{"phonout", required_argument, 0, 0x108},
 		{"pho",     no_argument,       0, 0x109},
 		{"ipa",     no_argument,       0, 0x10a},
+		{"version", no_argument,       0, 0x10b},
 		{0, 0, 0, 0}
 		};
 
@@ -511,11 +510,9 @@ int main (int argc, char **argv)
 	espeak_VOICE voice_select;
 	char filename[200];
 	char voicename[40];
-	char dictname[40];
 
 	voicename[0] = 0;
 	mbrola_name[0] = 0;
-	dictname[0] = 0;
 	wavefile[0] = 0;
 	filename[0] = 0;
 	option_linelength = 0;
@@ -607,7 +604,6 @@ int main (int argc, char **argv)
 			init_path(argv[0],data_path);
 			printf("\nspeak text-to-speech: %s   Data at: %s\n%s",version_string,path_home,help_text);
 			exit(0);
-			break;
 
 		case 'k':
 			option_capitals = atoi(optarg2);
@@ -728,6 +724,11 @@ int main (int argc, char **argv)
 			option_phonemes = 3;
 			break;
 
+		case 0x10b:  // --version
+			init_path(argv[0],data_path);
+			printf("speak text-to-speech: %s   Data at: %s\n",version_string,path_home);
+			exit(0);
+
 		default:
 			exit(0);
 		}
